==> hoteldruid-mod-nl_3.0.3-1.tar.gz: nl/inizio.php <==
<?php

switch ($messaggio) {

case "Menù principale dell'anno":             	$messaggio = "Agenda"; break;
case "Inserisci una nuova prenotazione":      	$messaggio = "Voeg een reservering toe"; break;
case "Gennaio":                               	$messaggio = "Januari"; break;
case "Febbraio":                              	$messaggio = "Februari"; break;
case "Marzo":                                 	$messaggio = "Maart"; break;
case "Maggio":                           	$messaggio = "Mei"; break;
case "Giugno":                            	$messaggio = "Juni"; break;
case "Luglio":                            	$messaggio = "Juli"; break;
case "Agosto":  				$messaggio = "Augustus"; break;
case "Ottobre":  				$messaggio = "Oktober"; break;
case "tutte le prenotazioni":  			$messaggio = "alle reserveringen"; break;
case "le spese e le entrate":  			$messaggio = "Rekeningen en betalingen"; break;
case "i periodi e le tariffe":  		$messaggio = "Periode en tarieven"; break;
case "tutti i clienti":  			$messaggio = "alle gasten"; break;
case "le regole di assegnazione":  		$messaggio = "bijzondere toewijzingen"; break;
case "Inserisci un nuovo cliente":		$messaggio = "Voeg een nieuwe gast toe"; break;
case "Spese ed entrate":  			$messaggio = "Cash receipts and payments"; break;
case "al":  					$messaggio = "tot"; break;
case "per":  					$messaggio = "voor"; break;
case "persone":	  				$messaggio = "personen"; break;
case "Inserisci o modifica i prezzi":  		$messaggio = "Voeg kamerprijzen toe of wijzig"; break;
case "Inserisci o modifica le regole di assegnazione":  $messaggio = "Voeg toe of wijzig de extra voorwaarden"; break;
case "Configura e personalizza":	$messaggio = "Configureren en aanpassen"; break;
case "richiedi l'anno":  			$messaggio = "Ga naar jaar"; break;
case "vai":  					$messaggio = "ga"; break;
case "Non esiste l'anno ":  			$messaggio = "Het jaar "; break;
case " nel database":  				$messaggio = " ontbreekt in de database"; break;
case "Crea l'anno":  				$messaggio = "Maak het jaar"; break;
case "Domenica":  				$messaggio = "Zondag"; break;
case "Lunedì":  				$messaggio = "Maandag"; break;
case "Martedì":  				$messaggio = "Dinsdag"; break;
case "Mercoledì":  				$messaggio = "Woensdag"; break;
case "Giovedì":  				$messaggio = "Donderdag"; break;
case "Venerdì":  				$messaggio = "Vrijdag"; break;
case "Sabato":	 		 		$messaggio = "Zaterdag"; break;
case "come giorno di inizio/fine locazione":	$messaggio = "als de dag van begin/einde huur"; break;
case "con periodi":  				$messaggio = "met"; break;
case "settimanali":  				$messaggio = "wekelijks"; break;
case "giornalieri":  				$messaggio = "dagelijks"; break;
case "e prenotazioni da":  			$messaggio = "en reserveringen van"; break;
case "a":  					$messaggio = "to"; break;
case "Importa dall'anno precedente prenotazioni, tariffe (compresi costi aggiuntivi), privilegi degli utenti e regole d'assegnazione.":  $messaggio = "Voeg in van vorig jaar de reserveringen, tarieven (inclusief extra kosten) gebruikers rechten en toewijzingsregels."; break;
case "Anno ":  					$messaggio = "Jaar "; break;
case " creato":  				$messaggio = " gemaakt"; break;
case "Non ci sono periodi che riguardano il ":  $messaggio = "Er zijn periodes met betrekking tot "; break;
case ", o il giorno di inizio/fine locazione era differente, sono stati importati solo i dati riguardanti costi aggiuntivi, caparra, nome delle tariffe, privilegi degli utenti e regole di assegnazione 2 e 3":	$messaggio = ", of de dag van begin/eind huur was verschillend, alleen gegevens over extra kosten, deposito, namen van tarieven, gebruikers rechten en toewijzingsregels 2 en 3 zijn geimporteerd"; break;
case "Attenzione</b></font>: i periodi del ":  	$messaggio = "Waarschuwing</b></font>: de periode van "; break;
case " finivano dopo quelli del ":  		$messaggio = " eindigd na de behoren bij "; break;
case " e vi erano":  				$messaggio = " en er zijn"; break;
case "prenotazioni che finivano dopo il limite posto al ":	$messaggio = "reserveringen die eindigen na de limiet gegeven voor "; break;
case ", queste prenotazioni non sono state importate":	$messaggio = ", deze reservering is niet geboekt"; break;
case "Anno già creato": 			$messaggio = "Jaar is reeds aangemaakt"; break;
case " Do":  					$messaggio = " Zo"; break;
case " Lu":  					$messaggio = " Ma"; break;
case " Ma":  					$messaggio = " Di"; break;
case " Me":  					$messaggio = " Wo"; break;
case " Gi":  					$messaggio = " DO"; break;
case " Ve":  					$messaggio = " Vr"; break;
case " Sa":  					$messaggio = " Za"; break;
case "Gen":  					$messaggio = "Jan"; break;
case "Feb":  					$messaggio = "Feb"; break;
case "Mar":  					$messaggio = "Mrt"; break;
case "Apr":  					$messaggio = "Apr"; break;
case "Mag":  					$messaggio = "Mei"; break;
case "Giu":  					$messaggio = "Jun"; break;
case "Lug":  					$messaggio = "Jul"; break;
case "Ago":  					$messaggio = "Aug"; break;
case "Set":  					$messaggio = "Sep"; break;
case "Ott":  					$messaggio = "Okt"; break;
case "Nov":  					$messaggio = "Nov"; break;
case "Dic":  					$messaggio = "Dec"; break;
case "Il formato dell'anno richiesto è sbagliato":	$messaggio = "Het formaat van het gevraagde jaar is fout"; break;
case "I mesi erano indicati erroneamente, sono stati inseriti i mesi da Gennaio a Dicembre":	$messaggio = "De maanden zijn verkeerd gekozen, ze zijn ingevoegd van Januarie to December"; break;
case "Cognome del cliente":  			$messaggio = "Achternaam gast"; break;
case "Data iniziale":  				$messaggio = "Startdatum"; break;
case "Data finale":  				$messaggio = "Einddatum"; break;
case "Tariffa completa":  			$messaggio = "Volledig tarief"; break;
case "Da pagare":  				$messaggio = "Te betalen"; break;
case "Pers":  					$messaggio = "Pers"; break;
case "Registra":  				$messaggio = "Boek"; break;
case "Entrata e pagato":  			$messaggio = "Check-in en betaald"; break;
case "Uscita e pagato":  			$messaggio = "Check-out en betaald"; break;
case "mostra tutte le date":  			$messaggio = "Laat alle dagen zien"; break;
case "Utente":  				$messaggio = "Gebruiker"; break;
case "Messaggi":  				$messaggio = "Reserveringen via internet"; break;
case "prenotazioni del mese di": 		$messaggio = "reservations in"; break;
case "visualizza": 				$messaggio = "view"; break;
case "Aprile":      				$messaggio = "April"; break;
case "Settembre":  				$messaggio = "September"; break;
case "Novembre":  				$messaggio = "November"; break;
case "Dicembre":  				$messaggio = "December"; break;
case "tabella con":  				$messaggio = "table with"; break;
case "disponibilità dal":  			$messaggio = "availability from"; break;
case "controlla":  				$messaggio = "check"; break;
case "anno successivo": 			$messaggio = "next year"; break;
case "anni successivi":  			$messaggio = "years later"; break;
case " nel ":  					$messaggio = " in "; break;
case "N&deg;":  				$messaggio = "N&deg;"; break;
case "Entrata":  				$messaggio = "Check-in"; break;
case "Uscita":  				$messaggio = "Check-out"; break;
case "Esci":  					$messaggio = "Logout"; break;
case "<span class=\"colred\">Avviso</span>: è consigliabile attendere fino al":	$messaggio = "<span class=\"colred\">Warning</span>: you are advised to wait until"; break;
case "per creare il nuovo anno, nel frattempo si possono aggiungere periodi oltre il":	$messaggio = "before creating the new year, meanwhile you can add periods beyond"; break;
case "dalla":  					$messaggio = "from the"; break;
case "tabella con i periodi e le tariffe":  	$messaggio = "table with periods and rates"; break;
case "anche senza creare un nuovo anno":  	$messaggio = "even without creating a new year"; break;
case "Non ho i permessi di scrittura sulla cartella dati":	$messaggio = "I don't have write permissions on dati folder"; break;
case "le statistiche":  			$messaggio = "the statistics"; break;
case "inventario e magazzini":  		$messaggio = "inventory and stockrooms"; break;
case "obsoleti":  				$messaggio = "obsolete"; break;
case "Ultimo aggiornamento":  			$messaggio = "Last update"; break;
case "Aggiorna":  				$messaggio = "Update"; break;
case "i documenti salvati":  			$messaggio = "saved documents"; break;
case "Punto vendita":  				$messaggio = "Point of sale"; break;
case "Non ho i permessi per creare nuove tabelle nel database":	$messaggio = "I don't have permissions to create new tables in the database"; break;
case "Benvenuto a HOTELDRUID":  		$messaggio = "Welcome to HOTELDRUID"; break;
case "Scegli la lingua":  			$messaggio = "Choose the language"; break;
case "crea il database":  			$messaggio = "create database"; break;
case "Promemoria":  				$messaggio = "Reminder"; break;
case "Questo utente non ha i privilegi per creare nuovi anni":	$messaggio = "This user has no privileges to create new years"; break;
case "Avviso":  				$messaggio = "Warning"; break;
case "nel database sono ancora disponibili periodi solo per meno di":	$messaggio = "in the database there are still available periods for only less than"; break;
case "mesi":  					$messaggio = "months"; break;
case "OK, ho capito":  				$messaggio = "OK, got it"; break;
case "Crea Anno":  				$messaggio = "Create Year"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-nl_3.0.8-1.tar.gz: nl/inizio.php <==
<?php

switch ($messaggio) {

case "Menù principale dell'anno":             	$messaggio = "Agenda"; break;
case "Inserisci una nuova prenotazione":      	$messaggio = "Voeg een reservering toe"; break;
case "Gennaio":                               	$messaggio = "Januari"; break;
case "Febbraio":                              	$messaggio = "Februari"; break;
case "Marzo":                                 	$messaggio = "Maart"; break;
case "Maggio":                           	$messaggio = "Mei"; break;
case "Giugno":                            	$messaggio = "Juni"; break;
case "Luglio":                            	$messaggio = "Juli"; break;
case "Agosto":  				$messaggio = "Augustus"; break;
case "Ottobre":  				$messaggio = "Oktober"; break;
case "tutte le prenotazioni":  			$messaggio = "alle reserveringen"; break;
case "le spese e le entrate":  			$messaggio = "Rekeningen en betalingen"; break;
case "i periodi e le tariffe":  		$messaggio = "Periode en tarieven"; break;
case "tutti i clienti":  			$messaggio = "alle gasten"; break;
case "le regole di assegnazione":  		$messaggio = "bijzondere toewijzingen"; break;
case "Inserisci un nuovo cliente":		$messaggio = "Voeg een nieuwe gast toe"; break;
case "Spese ed entrate":  			$messaggio = "Cash receipts and payments"; break;
case "al":  					$messaggio = "tot"; break;
case "per":  					$messaggio = "voor"; break;
case "persone":	  				$messaggio = "personen"; break;
case "Inserisci o modifica i prezzi":  		$messaggio = "Voeg kamerprijzen toe of wijzig"; break;
case "Inserisci o modifica le regole di assegnazione":  $messaggio = "Voeg toe of wijzig de extra voorwaarden"; break;
case "Configura e personalizza":	$messaggio = "Configureren en aanpassen"; break;
case "richiedi l'anno":  			$messaggio = "Ga naar jaar"; break;
case "vai":  					$messaggio = "ga"; break;
case "Non esiste l'anno ":  			$messaggio = "Het jaar "; break;
case " nel database":  				$messaggio = " ontbreekt in de database"; break;
case "Crea l'anno":  				$messaggio = "Maak het jaar"; break;
case "Domenica":  				$messaggio = "Zondag"; break;
case "Lunedì":  				$messaggio = "Maandag"; break;
case "Martedì":  				$messaggio = "Dinsdag"; break;
case "Mercoledì":  				$messaggio = "Woensdag"; break;
case "Giovedì":  				$messaggio = "Donderdag"; break;
case "Venerdì":  				$messaggio = "Vrijdag"; break;
case "Sabato":	 		 		$messaggio = "Zaterdag"; break;
case "come giorno di inizio/fine locazione":	$messaggio = "als de dag van begin/einde huur"; break;
case "con periodi":  				$messaggio = "met"; break;
case "settimanali":  				$messaggio = "wekelijks"; break;
case "giornalieri":  				$messaggio = "dagelijks"; break;
case "e prenotazioni da":  			$messaggio = "en reserveringen van"; break;
case "a":  					$messaggio = "to"; break;
case "Importa dall'anno precedente prenotazioni, tariffe (compresi costi aggiuntivi), privilegi degli utenti e regole d'assegnazione.":  $messaggio = "Voeg in van vorig jaar de reserveringen, tarieven (inclusief extra kosten) gebruikers rechten en toewijzingsregels."; break;
case "Anno ":  					$messaggio = "Jaar "; break;
case " creato":  				$messaggio = " gemaakt"; break;
case "Non ci sono periodi che riguardano il ":  $messaggio = "Er zijn periodes met betrekking tot "; break;
case ", o il giorno di inizio/fine locazione era differente, sono stati importati solo i dati riguardanti costi aggiuntivi, caparra, nome delle tariffe, privilegi degli utenti e regole di assegnazione 2 e 3":	$messaggio = ", of de dag van begin/eind huur was verschillend, alleen gegevens over extra kosten, deposito, namen van tarieven, gebruikers rechten en toewijzingsregels 2 en 3 zijn geimporteerd"; break;
case "Attenzione</b></font>: i periodi del ":  	$messaggio = "Waarschuwing</b></font>: de periode van "; break;
case " finivano dopo quelli del ":  		$messaggio = " eindigd na de behoren bij "; break;
case " e vi erano":  				$messaggio = " en er zijn"; break;
case "prenotazioni che finivano dopo il limite posto al ":	$messaggio = "reserveringen die eindigen na de limiet gegeven voor "; break;
case ", queste prenotazioni non sono state importate":	$messaggio = ", deze reservering is niet geboekt"; break;
case "Anno già creato": 			$messaggio = "Jaar is reeds aangemaakt"; break;
case "Il formato dell'anno richiesto è sbagliato":	$messaggio = "Het formaat van het gevraagde jaar is fout"; break;
case "I mesi erano indicati erroneamente, sono stati inseriti i mesi da Gennaio a Dicembre":	$messaggio = "De maanden zijn verkeerd gekozen, ze zijn ingevoegd van Januarie to December"; break;
case "Cognome del cliente":  			$messaggio = "Achternaam gast"; break;
case "Data iniziale":  				$messaggio = "Startdatum"; break;
case "Data finale":  				$messaggio = "Einddatum"; break;
case "Tariffa completa":  			$messaggio = "Volledig tarief"; break;
case "Da pagare":  				$messaggio = "Te betalen"; break;
case "Pers":  					$messaggio = "Pers"; break;
case "Registra":  				$messaggio = "Boek"; break;
case "Entrata e pagato":  			$messaggio = "Check-in en betaald"; break;
case "Uscita e pagato":  			$messaggio = "Check-out en betaald"; break;
case "mostra tutte le date":  			$messaggio = "Laat alle dagen zien"; break;
case "Utente":  				$messaggio = "Gebruiker"; break;
case "Messaggi":  				$messaggio = "Reserveringen via internet"; break;
case "prenotazioni del mese di": 		$messaggio = "reservations in"; break;
case "visualizza": 				$messaggio = "view"; break;
case "Aprile":      				$messaggio = "April"; break;
case "Settembre":  				$messaggio = "September"; break;
case "Novembre":  				$messaggio = "November"; break;
case "Dicembre":  				$messaggio = "December"; break;
case "tabella con":  				$messaggio = "table with"; break;
case "disponibilità dal":  			$messaggio = "availability from"; break;
case "controlla":  				$messaggio = "check"; break;
case "anno successivo": 			$messaggio = "next year"; break;
case "anni successivi":  			$messaggio = "years later"; break;
case " nel ":  					$messaggio = " in "; break;
case "N&deg;":  				$messaggio = "N&deg;"; break;
case "Entrata":  				$messaggio = "Check-in"; break;
case "Uscita":  				$messaggio = "Check-out"; break;
case "Esci":  					$messaggio = "Logout"; break;
case "<span class=\"colred\">Avviso</span>: è consigliabile attendere fino al":	$messaggio = "<span class=\"colred\">Warning</span>: you are advised to wait until"; break;
case "per creare il nuovo anno, nel frattempo si possono aggiungere periodi oltre il":	$messaggio = "before creating the new year, meanwhile you can add periods beyond"; break;
case "dalla":  					$messaggio = "from the"; break;
case "tabella con i periodi e le tariffe":  	$messaggio = "table with periods and rates"; break;
case "anche senza creare un nuovo anno":  	$messaggio = "even without creating a new year"; break;
case "Non ho i permessi di scrittura sulla cartella dati":	$messaggio = "I don't have write permissions on dati folder"; break;
case "le statistiche":  			$messaggio = "the statistics"; break;
case "inventario e magazzini":  		$messaggio = "inventory and stockrooms"; break;
case "obsoleti":  				$messaggio = "obsolete"; break;
case "Ultimo aggiornamento":  			$messaggio = "Last update"; break;
case "Aggiorna":  				$messaggio = "Update"; break;
case "i documenti salvati":  			$messaggio = "saved documents"; break;
case "Punto vendita":  				$messaggio = "Point of sale"; break;
case "Non ho i permessi per creare nuove tabelle nel database":	$messaggio = "I don't have permissions to create new tables in the database"; break;
case "Benvenuto a HOTELDRUID":  		$messaggio = "Welcome to HOTELDRUID"; break;
case "Scegli la lingua":  			$messaggio = "Choose the language"; break;
case "crea il database":  			$messaggio = "create database"; break;
case "Promemoria":  				$messaggio = "Reminder"; break;
case "Questo utente non ha i privilegi per creare nuovi anni":	$messaggio = "This user has no privileges to create new years"; break;
case "Avviso":  				$messaggio = "Warning"; break;
case "nel database sono ancora disponibili periodi solo per meno di":	$messaggio = "in the database there are still available periods for only less than"; break;
case "mesi":  					$messaggio = "months"; break;
case "OK, ho capito":  				$messaggio = "OK, got it"; break;
case "Crea Anno":  				$messaggio = "Create Year"; break;
case "Nota":  					$messaggio = "Notice"; break;
case "l'anno":  				$messaggio = "year"; break;
case "verrà archiviato automaticamente il":  	$messaggio = "will be automatically archived on"; break;
case "nel frattempo si possono aggiungere periodi oltre il":	$messaggio = "meanwhile you can add periods beyond"; break;
case "ricordarsi di tornare al":  		$messaggio = "remember to come back to"; break;
case "una volta conclusa la consultazione del":	$messaggio = "once finished consulting the"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
